from django.apps import AppConfig
from django.utils.translation import ugettext_lazy as _


class DjangoRestFileManagerConfig(AppConfig):
    name = 'djangorestfilemanager'
    verbose_name = _('Django Rest File Manager Config')
